#!/usr/bin/python3
import os

# This script uses green.svg and generates the following files from it:
#
# aqua.svg
# blue.svg
# brown.svg
# grey.svg
# orange.svg
# pink.svg
# purple.svg
# red.svg
# sand.svg
# teal.svg

# It uses the following color table to do so:
COLORS = {}
COLORS["aqua"] = "66a8cb"
COLORS["blue"] = "5972c3"
COLORS["brown"] = "997052"
COLORS["grey"] = "999999"
COLORS["orange"] = "cc823f"
COLORS["pink"] = "ce6ca2"
COLORS["purple"] = "8463c5"
COLORS["red"] = "b74c4a"
COLORS["sand"] = "c4a660"
COLORS["teal"] = "59c3ad"
COLORS["yellow"] = "e7bc0d"

GREEN_COLOR = "8bb158"

for color in COLORS:
    value = COLORS[color]
    os.system("sed 's/%s/%s/g' green.svg > %s.svg" % (GREEN_COLOR, value, color))



#!/usr/bin/python3
import os
import subprocess
import sys

colors = ["Aqua", "Blue", "Brown", "Green", "Grey", "Orange", "Pink", "Purple", "Red", "Sand", "Teal", "Yellow"]
sizes = ["16", "22", "24", "32", "48", "64", "96", "128"]


def generate_color(color):
    source = "places/" + color.lower() + ".svg"
    if color == "Green":
        theme_dir = "../usr/share/icons/Mint-Y-Legacy"
    else:
        theme_dir = "../usr/share/icons/Mint-Y-Legacy-%s" % color
    os.system("mkdir -p %s" % theme_dir)

    for size in sizes:
        icon_dir = os.path.join(theme_dir, "places", size)
        icon_dir_2x = os.path.join(theme_dir, "places", size + "@2x")
        os.system("mkdir -p %s" % icon_dir)
        os.system("mkdir -p %s" % icon_dir_2x)
        names = subprocess.check_output("inkscape -S %s | grep -E \"_%s\" | sed 's/\,.*$//'" % (source, size), shell=True).decode("UTF-8")
        for name in names.split("\n"):
            if "_" in name:
                icon_name = name.replace("_%s" % size, "")
                icon_path = os.path.join(icon_dir, icon_name + ".png")
                print("Rendering %s" % icon_path)
                os.system("inkscape --export-id=%s \
                               --export-id-only \
                               --export-filename=%s %s >/dev/null \
                     && optipng -o7 --quiet %s" % (name, icon_path, source, icon_path))

                icon_path = os.path.join(icon_dir_2x, icon_name + ".png")
                print("Rendering %s" % icon_path)
                os.system("inkscape --export-id=%s \
                               --export-id-only \
                               --export-dpi=192 \
                               --export-filename=%s %s >/dev/null \
                     && optipng -o7 --quiet %s" % (name, icon_path, source, icon_path))

def parse_arg(arg):
    if arg == "All":
        for color in colors:
            generate_color(color)
    else:
        generate_color(arg)

def usage():
    print ("Usage: render_places.py color \n\
    color can be: Aqua, Blue, Brown, Green, Grey, Orange, Pink, Purple, Red, Sand, Teal, Yellow or All.")
    sys.exit(1)

if len(sys.argv) != 2:
    usage()
else:
    parse_arg(sys.argv[1])



#!/usr/bin/python3
#
# Legal Stuff:
#
# This file is part of the Moka Icon Theme and is free software; you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free Software
# Foundation; version 3.
#
# This file is part of the Moka Icon Theme and is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, see <https://www.gnu.org/licenses/lgpl-3.0.txt>
#
#
# Thanks to the GNOME icon developers for the original version of this script
import os
import sys
import xml.sax
import subprocess
import argparse

INKSCAPE = '/usr/bin/inkscape'
OPTIPNG = '/usr/bin/optipng'
MAINDIR = '../usr/share/icons/Mint-Y-Legacy'
SOURCES = ['apps', 'categories']

# the resolution that non-hi-dpi icons are rendered at (may be 90 or 96 depending on your inkscape build)
inkscape_version = str(subprocess.check_output(['inkscape', '-V'])).split(' ')[1].split('.')
inkscape_version = float(inkscape_version[0] + '.' + inkscape_version[1])
if inkscape_version < 0.92: # inkscape version 0.92 changed the default dpi from 90 to 96
    DPI_1_TO_1 = 90
else:
    DPI_1_TO_1 = 96
# DPI multipliers to render at
DPIS = [1, 2] # for hidpi icons change to [1, 2] (not yet supported in Mint-Y)

def main(args, SRC):

    def optimize_png(png_file):
        if os.path.exists(OPTIPNG):
            process = subprocess.Popen([OPTIPNG, '-quiet', '-o7', png_file])
            process.wait()

    def inkscape_render_rect(icon_file, rect, dpi, output_file):
        process = subprocess.Popen([INKSCAPE, '--batch-process', '--export-dpi', str(dpi),
               '-i', rect,
               '-o', output_file, icon_file])
        process.wait()
        optimize_png(output_file)

    class ContentHandler(xml.sax.ContentHandler):
        ROOT = 0
        SVG = 1
        LAYER = 2
        OTHER = 3
        TEXT = 4
        def __init__(self, path, file_name, force=False, filter=None):
            self.stack = [self.ROOT]
            self.inside = [self.ROOT]
            self.path = path
            self.rects = []
            self.state = self.ROOT
            self.chars = ""
            self.force = force
            self.filter = filter
            self.file_name = file_name

        def endDocument(self):
            pass

        def startElement(self, name, attrs):
            if self.inside[-1] == self.ROOT:
                if name == "svg":
                    self.stack.append(self.SVG)
                    self.inside.append(self.SVG)
                    return
            elif self.inside[-1] == self.SVG:
                for attr in attrs.values():
                    if attr == 'Baseplate':
                        self.stack.append(self.LAYER)
                        self.inside.append(self.LAYER)
                        self.context = None
                        self.icon_name = None
                        self.rects = []
                        return
            elif self.inside[-1] == self.LAYER:
                for attr in attrs.values():
                    if attr == "context":
                        self.stack.append(self.TEXT)
                        self.inside.append(self.TEXT)
                        self.text='context'
                        self.chars = ""
                        return
                    if attr == "icon-name":
                        self.stack.append(self.TEXT)
                        self.inside.append(self.TEXT)
                        self.text='icon-name'
                        self.chars = ""
                        return
                    if name == "rect":
                        self.rects.append(attrs)

            self.stack.append(self.OTHER)


        def endElement(self, name):
            stacked = self.stack.pop()
            if self.inside[-1] == stacked:
                self.inside.pop()

            if stacked == self.TEXT and self.text is not None:
                assert self.text in ['context', 'icon-name']
                if self.text == 'context':
                    self.context = self.chars
                elif self.text == 'icon-name':
                    self.icon_name = self.chars
                self.text = None
            elif stacked == self.LAYER:
                assert self.icon_name
                assert self.context

                if self.filter is not None and not self.icon_name in self.filter:
                    return

                if (self.icon_name != self.file_name):
                    print(f"icon name in {self.file_name} is wrong: {self.icon_name}")
                    sys.exit(1)
                for rect in self.rects:
                    for dpi_factor in DPIS:
                        width = rect['width']
                        height = rect['height']
                        id = rect['id']
                        dpi = DPI_1_TO_1 * dpi_factor

                        size_str = "%s" % (width)
                        if dpi_factor != 1:
                            size_str += "@%sx" % dpi_factor

                        dir = os.path.join(MAINDIR, self.context, size_str)
                        outfile = os.path.join(dir, self.icon_name+'.png')
                        if not os.path.exists(dir):
                            os.makedirs(dir)
                        # Do a time based check!
                        if self.force or not os.path.exists(outfile):
                            print (self.context, self.icon_name, self.file_name)
                            inkscape_render_rect(self.path, id, dpi, outfile)
                            #sys.stdout.write('.')
                        else:
                            stat_in = os.stat(self.path)
                            stat_out = os.stat(outfile)
                            if stat_in.st_mtime > stat_out.st_mtime:
                                print (self.context, self.icon_name, self.file_name)
                                inkscape_render_rect(self.path, id, dpi, outfile)
                                #sys.stdout.write('.')
                            #else:
                            #    sys.stdout.write('-')
                        sys.stdout.flush()
                #sys.stdout.write('\n')
                #sys.stdout.flush()

        def characters(self, chars):
            self.chars += chars.strip()


    if not args.svg:
        if not os.path.exists(MAINDIR):
            os.mkdir(MAINDIR)
        print ('')
        print ('Rendering from SVGs in', SRC)
        print ('')
        for file in sorted(os.listdir(SRC)):
            if file[-4:] == '.svg':
                path = os.path.join(SRC, file)
                icon_name = file.replace(".svg", "")
                handler = ContentHandler(path, icon_name)
                xml.sax.parse(open(path), handler)
        print ('')
    else:
        path = os.path.join(SRC, args.svg + '.svg')

        if os.path.exists(os.path.join(path)):
            icon_name = args.svg
            handler = ContentHandler(path, icon_name, True, filter=args.filter)
            xml.sax.parse(open(path), handler)
        else:
            # icon not in this directory, try the next one
            pass

parser = argparse.ArgumentParser(description='Render icons from SVG to PNG')

parser.add_argument('svg', type=str, nargs='?', metavar='SVG',
                    help="Optional SVG names (without extensions) to render. If not given, render all icons")
parser.add_argument('filter', type=str, nargs='?', metavar='FILTER',
                    help="Optional filter for the SVG file")

args = parser.parse_args()

for source in SOURCES:
    if os.path.exists(os.path.join('.', source)):
        SRC = os.path.join('.', source)
        main(args, SRC)



#!/usr/bin/python3

import os
import subprocess
import sys

MINTY_DIR = os.path.join(os.getcwd(), "..", "usr", "share", "icons")
DEADLINK_DIR = os.path.join(os.getcwd(), "..")

def check_symbolic_links_list():
    with open(SYMBOLIC_APPS_FILE, "r") as symbolic_apps_file:
        line_no = 0
        for symbolic_link_ref in symbolic_apps_file:
            line_no = line_no+1
            if " <- " not in symbolic_link_ref:
                print("Wrong symbolic link reference in line " + str(line_no) + ": " + symbolic_link_ref)
            else:
                target, symlink = symbolic_link_ref.split(" <- ")
                # check if target.svg exists
                target_svg = target.rsplit(".", 1)[0] + ".svg"
                CHECK_DIR = SRC_DIR
                if sys.argv[1] == "mimetypes":
                    CHECK_DIR += "/64"
                if not os.path.exists(os.path.join(CHECK_DIR, target_svg)):
                    print(target_svg + " does not exist (line " + str(line_no) + ")")
                    #pass

                create_symbolic_link(target, symlink)

def create_symbolic_link(target, symlink):
    for apps_pixel in os.listdir(APPS_DIR):
        if apps_pixel != "symbolic":
            target_path = os.path.join(APPS_DIR, apps_pixel, target).rstrip()
            symlink_path = os.path.join(APPS_DIR, apps_pixel, symlink).rstrip()
            if not os.path.islink(symlink_path):
                subprocess.call(['ln', '-s', '-r', target_path, symlink_path])
                print(symlink_path + " created")

def delete_symbolic_links():
    subprocess.call(['find', APPS_DIR, '-type', 'l', '-delete'])


if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("Pass argument: ")
        print("    apps")
        print("    categories")
        print("    mimetypes")
        print(" ")
        print("    show-deadlinks")
        print("    delete-deadlinks")
        print("    delete-symbolic-apps")
        print("    delete-symbolic-categories")
    else:
        if sys.argv[1] in ["apps", "categories", "mimetypes"]:
            SYMBOLIC_APPS_FILE = os.path.join(os.getcwd(), "symbolic-" + sys.argv[1] + "-list")
            SRC_DIR = os.path.join(os.getcwd(), sys.argv[1])
            APPS_DIR = os.path.join(os.getcwd(), "..", "usr", "share", "icons", "Mint-Y-Legacy", sys.argv[1])

            print("Creating symbolic links in " + sys.argv[1] + " directories...")
            check_symbolic_links_list()
            print("Done!")
        elif sys.argv[1] in ['delete-symbolic-apps']:
            APPS_DIR = os.path.join(os.getcwd(), "..", "usr", "share", "icons", "Mint-Y-Legacy", "apps")
            delete_symbolic_links()
        elif sys.argv[1] in ['delete-symbolic-categories']:
            APPS_DIR = os.path.join(os.getcwd(), "..", "usr", "share", "icons", "Mint-Y-Legacy", "categories")
            delete_symbolic_links()
        elif sys.argv[1] == 'show-deadlinks':
            os.chdir(DEADLINK_DIR)
            subprocess.call(DEADLINK_DIR + "/deadlinks")
        elif sys.argv[1] == 'delete-deadlinks':
            subprocess.call(['find', '-L', MINTY_DIR, '-type', 'l', '-delete'])
        else:
            print("Wrong argument! Valid arguments are:")
            print("    apps")
            print("    categories")
            print("    mimetypes")
            print(" ")
            print("    show-deadlinks")
            print("    delete-deadlinks")
            print("    delete-symbolic-apps")
            print("    delete-symbolic-categories")
